@@ -2,29 +2,50 @@ package Firefox::Marionette::ShadowRoot;
 
 use strict;
 use warnings;
-use parent qw(Firefox::Marionette::LocalObject);
 
-our $VERSION = '1.67_02';
+our $VERSION = '1.19';
 
 sub IDENTIFIER { return 'shadow-6066-11e4-a52e-4f735466cecf' }
 
+sub new {
+    my ( $class, $browser, %parameters ) = @_;
+    my $shadow_root = bless {
+        browser => $browser,
+        %parameters
+    }, $class;
+    return $shadow_root;
+}
+
+sub TO_JSON {
+    my ($self) = @_;
+    my $json = { IDENTIFIER() => $self->uuid() };
+    return $json;
+}
+
+sub uuid {
+    my ($self) = @_;
+    return $self->{ IDENTIFIER() };
+}
+
 1;    # Magic true value required at end of module
 __END__
 
 =head1 NAME
 
-Firefox::Marionette::ShadowRoot - Represents a Firefox shadow root retrieved using the Marionette protocol
+Firefox::Marionette::ShadowRoot - Represents a Firefox element retrieved using the Marionette protocol
 
 =head1 VERSION
 
-Version 1.67_02
+Version 1.19
 
 =head1 SYNOPSIS
 
     use Firefox::Marionette();
     use Cwd();
 
-    my $firefox = Firefox::Marionette->new()->go('file://' . Cwd::cwd() . '/t/data/elements.html');
+    my $firefox = Firefox::Marionette->new()->go('https://metacpan.org/');
+
+    $firefox->go('file://' . CWd::cwd() . 't/data/shadow.html');
     $firefox->find_class('add')->click();
     my $shadow_root = $firefox->find_tag('custom-square')->shadow_root();
 
@@ -36,21 +57,19 @@ Version 1.67_02
 
 This module handles the implementation of a Firefox Shadow Root using the Marionette protocol
 
-=head1 CONSTANTS
+=head1 SUBROUTINES/METHODS
 
 =head2 IDENTIFIER
 
 returns the L<shadow root identifier|https://www.w3.org/TR/webdriver/#shadow-root>
 
-=head1 SUBROUTINES/METHODS
-
 =head2 new
 
-returns a new L<shadow root|Firefox::Marionette::ShadowRoot>.
+returns a new L<element|Firefox::Marionette::ShadowRoot>.
 
 =head2 uuid
 
-returns the browser generated UUID connected with this L<shadow root|Firefox::Marionette::ShadowRoot>.
+returns the browser generated UUID connected with this L<element|Firefox::Marionette::ShadowRoot>.
 
 =head1 DIAGNOSTICS
 
@@ -78,7 +97,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2024, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2021, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
